@@ -797,7 +797,11 @@ Fiber.ImageSelectDialog = BaseFileSelectDialog.extend({
 		function thumbnail_formatter(value, row_data) {
 			// insert the url that ckeditor looks for. Use HTML5 data attribute instead?
 			// TODO: use image checksum for cache busting?
-			return '<span style="display: none;">' + row_data.image_url + '</span>' + '<img src="' + row_data.image_url + '?_c=' + encodeURIComponent(row_data.url) + '" title="' + row_data.title + '"/>';
+			var thumbnail_url = row_data.thumbnail_url;
+			if (thumbnail_url === null) {
+				thumbnail_url = row_data.image_url;
+			}
+			return '<span style="display: none;">' + row_data.image_url + '</span>' + '<img src="' + thumbnail_url + '?_c=' + encodeURIComponent(row_data.url) + '" title="' + row_data.title + '"/>';
 		}
 
 		this.select_grid.simple_datagrid({
